@@ -76,7 +76,7 @@ class Station():
         self._uri = None            # list, links to ressources, landing pages
         
         # data and products
-        self.__datacheck = False    # check if data and products have been asked for already
+        self._datacheck = False    # check if data and products have been asked for already
         self._data = None           # list of associated dataobjects
         self._products = None       # list of available products
         
@@ -218,9 +218,9 @@ class Station():
             3 = elaborated products
         """
         # check if data has already been asked for
-        if not self.__datacheck:
+        if not self._datacheck:
             self._setData()
-            self.__datacheck = True
+            self._datacheck = True
             
         if not isinstance(self._data, pd.DataFrame):
             # _data is not a dataframe but contains a string...
@@ -248,9 +248,9 @@ class Station():
 
         """
         # check if data has already bee asked for
-        if not self.__datacheck:
+        if not self._datacheck:
             self._setData()
-            self.__datacheck = True
+            self._datacheck = True
         
         if not isinstance(self._products, pd.DataFrame):
             return self._products
@@ -336,16 +336,12 @@ class Station():
         values =  self.__dict__.values()
         dictionary = dict(zip(newKeys,values))
         
-        # remove data and products from the dict to get a shorter
-        # summary of information about station
-        if 'data' in dictionary:
-            del dictionary['data']
-            
-        if 'products' in dictionary:
-            del dictionary['products']
-            
-        if 'valid' in dictionary:
-            del dictionary['valid']
+        # remove some of the __dictionary__ keys to get a shorter
+        # summary of information about the station
+        
+        remove = ['data', 'products', 'valid', 'datacheck']
+        dictionary = {key: value for key, value in dictionary.items() if key not in remove}
+        
         
         if fmt == 'dict':
             return dictionary
@@ -674,24 +670,24 @@ def getList(theme=['AS','ES','OS'], ids=None):
         return stationList
     
     defaulttheme=['AS','ES','OS']    
-     # make sure input is in uppercase    
-    try:        
-        if isinstance(theme, str):            
-            if not theme.upper() in defaulttheme:
-                raise Exception('theme')
-        else:
-           theme = [x.upper() for x in theme]                  
-           
-    except:
-        # looks like input is not a string and/or not an iterable str.
-        # comparison failed. Revert to default values, return all certified stations.
-        theme=['AS','ES','OS']
+    
+    # make sure input is a list and in uppercase    
+    
+    if isinstance(theme, str):
+        theme = [theme.upper()]
+    elif isinstance(theme, list):
+        theme = [x.upper() for x in theme]
+    if not isinstance(theme, list) or not (set(defaulttheme) & set(theme)):
+        # looks like input is not a theme.
+        # Revert to default values, return all certified stations.
+        theme=defaulttheme
     
     # get station list, by default returns all icos stations
     stations = getIdList()
     # filter by theme
     stations = stations[stations.theme.isin(theme)]
     
+    
     stationList = []
     for s in tqdm(stations.id):
         stationList.append(get(s))
